package utils

import (
	"fmt"
	"net/http"
)

// NewHTTPError creates a HTTPError.
func NewHTTPError(statusCode int, err error) HTTPError {
	return HTTPError{
		StatusCode: statusCode,
		Err:        err,
	}
}

// NewHTTPErrorf creates a HTTPError.
func NewHTTPErrorf(statusCode int, err string, args ...interface{}) HTTPError {
	return HTTPError{
		StatusCode: statusCode,
		Err:        fmt.Errorf(err, args...),
	}
}

// HTTPBadRequest returns a StatusBadRequest error.
func HTTPBadRequest(err error) HTTPError {
	return NewHTTPError(http.StatusBadRequest, err)
}

// HTTPInternalServerError returns a StatusBadRequest error.
func HTTPInternalServerError(err error) HTTPError {
	return NewHTTPError(http.StatusInternalServerError, err)
}

// HTTPError wraps a http status code and a regular error.
type HTTPError struct {
	StatusCode int
	Err        error
}

func (e HTTPError) Error() string {
	msg := fmt.Sprintf("%d: %s", e.StatusCode, http.StatusText(e.StatusCode))
	if e.Err != nil {
		msg += ": " + e.Err.Error()
	}

	return msg
}
